//////////////////////////////////////////////////////////////////////////////////////////////////
// File Name: MapItem.cs
//      Date: 06/01/2006
// Copyright (c) 2006 Michael LaLena. All rights reserved.  (www.lalena.com)
// Permission to use, copy, modify, and distribute this Program and its documentation,
//  if any, for any purpose and without fee is hereby granted, provided that:
//   (i) you not charge any fee for the Program, and the Program not be incorporated
//       by you in any software or code for which compensation is expected or received;
//   (ii) the copyright notice listed above appears in all copies;
//   (iii) both the copyright notice and this Agreement appear in all supporting documentation; and
//   (iv) the name of Michael LaLena or lalena.com not be used in advertising or publicity
//          pertaining to distribution of the Program without specific, written prior permission. 
///////////////////////////////////////////////////////////////////////////////////////////////////
using System;
using System.Collections.Generic;
using System.Text;

namespace AntGP
{
    /// <summary>
    /// Static class containing information on the items that can be placed on the map.
    /// </summary>
    public class MapItem
    {
        /// <summary>
        /// Static constructor.
        /// </summary>
        static MapItem()
        {
        }

        /// <summary>
        /// Enum of the different items that can appear on the map.
        /// </summary>
        public enum Item
        {
            /// <summary>Nothing</summary>
            Nothing,
            /// <summary>A wall that cannot be passed.</summary>
            Obstacle,
            /// <summary>Water that can only be crossed by using a leaf, or an ant sacrificing itself to build a bridge.</summary>
            Water,
            /// <summary>An ant that has moved into water and died.</summary>
            DeadAnt,
            /// <summary>An ant carrying nothing.</summary>
            Ant,
            /// <summary>An ant with food.</summary>
            AntWithFood,
            /// <summary>An ant carrying a leaf.</summary>
            AntWithLeaf,
            /// <summary>A tree that ants can gather leaves from.</summary>
            Tree,
            /// <summary>A leaf that has been dropped by an ant.</summary>
            Leaf,
            /// <summary>A leaf that has been dropped on water by an ant.</summary>
            LeafOnWater,
            /// <summary>The home base (nest) for the ant colony.</summary>
            Nest,
            /// <summary>Food requiring 1 ant to lift.</summary>
            Food1,
            /// <summary>Food requiring 2 ants to lift.</summary>
            Food2,
            /// <summary>Food requiring 3 ants to lift.</summary>
            Food3,
            /// <summary>Food requiring 4 ants to lift.</summary>
            Food4,
            /// <summary>Food requiring 5 ants to lift.</summary>
            Food5,
            /// <summary>Food requiring 6 ants to lift.</summary>
            Food6,
            /// <summary>Food requiring 7 ants to lift.</summary>
            Food7,
            /// <summary>Food requiring 8 ants to lift.</summary>
            Food8,
            /// <summary>Food requiring 9 ants to lift.</summary>
            Food9,
            /// <summary>Special value that can be used in comparisons to match any food type.</summary>
            AnyFood
        }

        /// <summary>
        /// Is a given map item food of any weight.
        /// </summary>
        /// <param name="item">The item to comarpe.</param>
        /// <returns>Is the item food.</returns>
        public static bool IsFood(MapItem.Item item)
        {
            if (item.ToString().IndexOf("Food") == 0)
            {
                return true;
            }

            return false;
        }

        /// <summary>
        /// The weight of a given type of food.
        /// </summary>
        /// <param name="item">The food item.</param>
        /// <returns>The weight of the food.</returns>
        public static int FoodWeight(MapItem.Item item)
        {
            if (IsFood(item))
            {
                return (Convert.ToInt32(item.ToString().Substring(4)));
            }

            return 0;
        }
    }
}
