//////////////////////////////////////////////////////////////////////////////////////////////////
// File Name: ProgramNode.cs
//      Date: 06/01/2006
// Copyright (c) 2006 Michael LaLena. All rights reserved.  (www.lalena.com)
// Permission to use, copy, modify, and distribute this Program and its documentation,
//  if any, for any purpose and without fee is hereby granted, provided that:
//   (i) you not charge any fee for the Program, and the Program not be incorporated
//       by you in any software or code for which compensation is expected or received;
//   (ii) the copyright notice listed above appears in all copies;
//   (iii) both the copyright notice and this Agreement appear in all supporting documentation; and
//   (iv) the name of Michael LaLena or lalena.com not be used in advertising or publicity
//          pertaining to distribution of the Program without specific, written prior permission. 
///////////////////////////////////////////////////////////////////////////////////////////////////
using System;

namespace AntGP
{
	/// <summary>
	/// Represents one node in the program tree.
	/// </summary>
	public class ProgramNode
	{
        /// <summary>
        /// Default Constructor.
        /// </summary>
		public ProgramNode()
		{
		}

        /// <summary>
        /// Constructor that sets the instruction and children values.
        /// </summary>
        /// <param name="instruction">The program instruction for this node.</param>
        /// <param name="leftChild">The left child of this node.</param>
        /// <param name="rightChild">The right child of this node.</param>
		public ProgramNode(Tokens.Instruction instruction, ProgramNode leftChild, ProgramNode rightChild)
		{
			this.instruction = instruction;
			this.left = leftChild;
			this.right = rightChild;
		}

        /// <summary>
        /// Private for the left child of this node.
        /// </summary>
		private ProgramNode left;
        /// <summary>
        /// The left child of this node.
        /// </summary>
		public ProgramNode Left
		{
			set 
			{
				left = value;
			}
			get 
			{
				return left;
			}
		}

        /// <summary>
        /// Private for the right child of this node.
        /// </summary>
		private ProgramNode right;
        /// <summary>
        /// The right child of this node.
        /// </summary>
		public ProgramNode Right
		{
			set 
			{
				right = value;
			}
			get 
			{
				return right;
			}
		}

        /// <summary>
        /// Private for the instruction for this node.
        /// </summary>
		private Tokens.Instruction instruction;
        /// <summary>
        /// The instruction for this node.
        /// </summary>
		public Tokens.Instruction Instruction
		{
			set
			{
				instruction = value;
			}
			get 
			{
				return instruction;
			}
		}
	}
}
